// $Id: EOAccess.h 1 2004-08-20 10:38:46Z znek $

#ifndef __GDLAccess_H__
#define __GDLAccess_H__

#import <GDLAccess/EODatabase.h>
#import <GDLAccess/EODatabaseChannel.h>
#import <GDLAccess/EODatabaseContext.h>

#import <GDLAccess/EOAdaptor.h>
#import <GDLAccess/EOAdaptorChannel.h>
#import <GDLAccess/EOAdaptorContext.h>
#import <GDLAccess/EOAttribute.h>
#import <GDLAccess/EOAttributeOrdering.h>
#import <GDLAccess/EOCustomValues.h>
#import <GDLAccess/EODatabase.h>
#import <GDLAccess/EODatabaseChannel.h>
#import <GDLAccess/EODatabaseContext.h>
#import <GDLAccess/EOEntity.h>
#import <GDLAccess/EOExpressionArray.h>
#import <GDLAccess/EOFExceptions.h>
#import <GDLAccess/EOGenericRecord.h>
#import <GDLAccess/EOKeySortOrdering.h>
#import <GDLAccess/EOModel.h>
#import <GDLAccess/EOObjectUniquer.h>
#import <GDLAccess/EOPrimaryKeyDictionary.h>
#import <GDLAccess/EOQuotedExpression.h>
#import <GDLAccess/EORelationship.h>
#import <GDLAccess/EOSQLExpression.h>
#import <GDLAccess/EOSQLQualifier.h>
#import <GDLAccess/EOAdaptorChannel+Attributes.h>
#import <GDLAccess/EOAdaptorDataSource.h>
#import <GDLAccess/EOAdaptorGlobalID.h>

#import <EOControl/EOGenericRecord.h>
#import <EOControl/EOKeyValueCoding.h>

// Kit class

@interface GDLAccess : NSObject
@end

#endif /* __GDLAccess_H__ */
