/*
  Copyright (C) 2000-2005 SKYRIX Software AG

  This file is part of SOPE.

  SOPE is free software; you can redistribute it and/or modify it under
  the terms of the GNU Lesser General Public License as published by the
  Free Software Foundation; either version 2, or (at your option) any
  later version.

  SOPE is distributed in the hope that it will be useful, but WITHOUT ANY
  WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
  License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with SOPE; see the file COPYING.  If not, write to the
  Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA
  02111-1307, USA.
*/

#ifndef __NGExtensions_H__
#define __NGExtensions_H__

#include <NGExtensions/AutoDefines.h>

#if defined(LIB_FOUNDATION_LIBRARY)
#  define NoZone nil
#else
#  define NoZone NULL
#endif

#include <NGExtensions/EODataSource+NGExtensions.h>
#include <NGExtensions/EOGrouping.h>
#include <NGExtensions/EOGroupingSet.h>
#include <NGExtensions/EOKeyGrouping.h>
#include <NGExtensions/EOQualifierGrouping.h>
#include <NGExtensions/NGBase64Coding.h>
#include <NGExtensions/NGBaseTypes.h>
#include <NGExtensions/NGBitSet.h>
#include <NGExtensions/NGBundleManager.h>
#include <NGExtensions/NGFileManager.h>
#include <NGExtensions/NGHashMap.h>
#include <NGExtensions/NGMemoryAllocation.h>
#include <NGExtensions/NGMerging.h>
#include <NGExtensions/NGQuotedPrintableCoding.h>
#include <NGExtensions/NGStack.h>
#include <NGExtensions/NSArray+enumerator.h>
#include <NGExtensions/NSBundle+misc.h>
#include <NGExtensions/NSCalendarDate+misc.h>
#include <NGExtensions/NSData+misc.h>
#include <NGExtensions/NSDictionary+misc.h>
#include <NGExtensions/NSURL+misc.h>
#include <NGExtensions/NSEnumerator+misc.h>
#include <NGExtensions/NSException+misc.h>
#include <NGExtensions/NSNull+misc.h>
#include <NGExtensions/NSObject+Logs.h>
#include <NGExtensions/NGLogging.h>
#include <NGExtensions/NSObject+Values.h>
#include <NGExtensions/NSProcessInfo+misc.h>
#include <NGExtensions/NSSet+enumerator.h>
#include <NGExtensions/NSString+Formatting.h>
#include <NGExtensions/NSString+Encoding.h>
#include <NGExtensions/NSString+Escaping.h>
#include <NGExtensions/NSString+misc.h>
#include <NGExtensions/NGObjectMacros.h>

#include <NGExtensions/EOQualifier+plist.h>
#include <NGExtensions/EOSortOrdering+plist.h>
#include <NGExtensions/EOFetchSpecification+plist.h>

#include <NGExtensions/IndexFunc.h>

// kit class

@interface NGExtensions : NSObject
@end

// linking ..

#define LINK_NGExtensions \
  void __link_NGExtensions(void) { \
    [NGExtensions self];   \
    __link_NGExtensions(); \
  }

#endif /* __NGExtensions_H__ */
