/*
  Copyright (C) 2002-2005 SKYRIX Software AG

  This file is part of SOPE.

  SOPE is free software; you can redistribute it and/or modify it under
  the terms of the GNU Lesser General Public License as published by the
  Free Software Foundation; either version 2, or (at your option) any
  later version.

  SOPE is distributed in the hope that it will be useful, but WITHOUT ANY
  WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
  License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with SOPE; see the file COPYING.  If not, write to the
  Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA
  02111-1307, USA.
*/

#ifndef __NGObjWeb_SoSubscriptionManager_H__
#define __NGObjWeb_SoSubscriptionManager_H__

#import <Foundation/NSObject.h>
#import <Foundation/NSDate.h>

/*
  SoSubscriptionManager
  
  This class (or singleton) is responsible for managing WebDAV URL
  subscriptions as documented in the Exchange WebDAV API.
*/

@class NSString, NSURL, NSArray, NSMutableDictionary, NSTimer;

@interface SoSubscriptionManager : NSObject
{
  NSMutableDictionary *idToSubscription;
  NSTimer *timer;
}

+ (id)sharedSubscriptionManager;

/* managing subscriptions */

- (NSString *)subscribeURL:(NSURL *)_url forObserver:(NSURL *)_callback
  type:(NSString *)_type delay:(NSTimeInterval)_delay
  lifetime:(NSTimeInterval)_lifetime;

- (NSString *)renewSubscription:(NSString *)_sid onURL:(NSURL *)_url;
- (BOOL)unsubscribeID:(NSString *)_sid           onURL:(NSURL *)_url;
- (id)pollSubscriptions:(NSArray *)_sids         onURL:(NSURL *)_url;

@end

#endif /* __NGObjWeb_SoSubscriptionManager_H__ */
