/*
  Copyright (C) 2000-2005 SKYRIX Software AG

  This file is part of SOPE.

  SOPE is free software; you can redistribute it and/or modify it under
  the terms of the GNU Lesser General Public License as published by the
  Free Software Foundation; either version 2, or (at your option) any
  later version.

  SOPE is distributed in the hope that it will be useful, but WITHOUT ANY
  WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
  License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with SOPE; see the file COPYING.  If not, write to the
  Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA
  02111-1307, USA.
*/

#ifndef __NGMail_NGMailAddress_H__
#define __NGMail_NGMailAddress_H__

#import <Foundation/NSObject.h>

@class NSString;

@interface NGMailAddress : NSObject < NSCopying, NSCoding >
{
@protected
  NSString *address;
  NSString *displayName;
  NSString *route;
}

+ (id)mailAddressWithAddress:(NSString *)_address
   displayName:(NSString *)_owner
   route:(NSString *)_route;

- (id)initWithAddress:(NSString *)_address
   displayName:(NSString *)_owner
   route:(NSString *)_route;

// equality

- (BOOL)isEqual:(id)_anObject;

// accessors

- (void)setAddress:(NSString *)_string;
- (NSString *)address;

- (void)setDisplayName:(NSString *)_displayName;
- (NSString *)displayName;

- (void)setRoute:(NSString *)_route;
- (NSString *)route;

@end

#endif /* __NGMail_NGMailAddress_H__ */
