/*
  Copyright (C) 2000-2005 SKYRIX Software AG

  This file is part of SOPE.

  SOPE is free software; you can redistribute it and/or modify it under
  the terms of the GNU Lesser General Public License as published by the
  Free Software Foundation; either version 2, or (at your option) any
  later version.

  SOPE is distributed in the hope that it will be useful, but WITHOUT ANY
  WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
  License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with SOPE; see the file COPYING.  If not, write to the
  Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA
  02111-1307, USA.
*/

#ifndef __DOM_H__
#define __DOM_H__

/*
  Standard DOM stuff
*/

#include <DOM/DOMAttribute.h>
#include <DOM/DOMCDATASection.h>
#include <DOM/DOMCharacterData.h>
#include <DOM/DOMComment.h>
#include <DOM/DOMDocument.h>
#include <DOM/DOMDocumentFragment.h>
#include <DOM/DOMDocumentType.h>
#include <DOM/DOMElement.h>
#include <DOM/DOMEntity.h>
#include <DOM/DOMEntityReference.h>
#include <DOM/DOMImplementation.h>
#include <DOM/DOMNode.h>
#include <DOM/DOMNotation.h>
#include <DOM/DOMProcessingInstruction.h>
#include <DOM/DOMSaxBuilder.h>
#include <DOM/DOMText.h>
#include <DOM/DOMXMLOutputter.h>
#include <DOM/DOMNamedNodeMap.h>

#endif /* __DOM_H__ */
