/*
  Copyright (C) 2000-2005 SKYRIX Software AG

  This file is part of SOPE.

  SOPE is free software; you can redistribute it and/or modify it under
  the terms of the GNU Lesser General Public License as published by the
  Free Software Foundation; either version 2, or (at your option) any
  later version.

  SOPE is distributed in the hope that it will be useful, but WITHOUT ANY
  WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
  License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with SOPE; see the file COPYING.  If not, write to the
  Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA
  02111-1307, USA.
*/

#ifndef __NGObjWeb_SoSubscription_H__
#define __NGObjWeb_SoSubscription_H__

#import <Foundation/NSObject.h>
#import <Foundation/NSDate.h>

/*
  SoSubscription
  
  This class holds the information of a single subscription. Usually you
  will never access SoSubscription objects directly.

  Subscription Types:
    update
    delete
    move
    any
    update/newmember
    pragma/<http...newmail>
*/

@class NSString, NSURL, NSMutableDictionary;

@interface SoSubscription : NSObject
{
  NSString       *sid;
  NSURL          *object;
  BOOL           trackChildren; /* depth header */
  NSURL          *observer;
  
  NSTimeInterval delay;
  NSTimeInterval lifetime;
  NSDate         *expireDate;   /* now + lifetime */
  NSString       *subscriptionType;
  
  unsigned       pending; /* keeps the number of events since last POLL */
}

- (id)initWithID:(NSString *)_sid
  url:(NSURL *)_url observer:(NSURL *)_callback
  type:(NSString *)_type delay:(NSTimeInterval)_delay
  lifetime:(NSTimeInterval)_lifetime;

/* accessors */

- (NSDate *)expirationDate;
- (NSString *)subscriptionID;
- (BOOL)hasEventsPending;

/* operations */

- (BOOL)isValidForURL:(NSURL *)_url;
- (BOOL)isExpired;
- (BOOL)renewSubscription;
- (void)resetEvents;

@end

#endif /* __NGObjWeb_SoSubscription_H__ */
